==> blancoNLpackGenerator-0.1.2-src.zip: blancoNLpackGenerator/blanco/main/blanco/nlpack/generator/task/valueobject/BlancoNLpackGeneratorPluginDirectory2JarProcessInput.java <==
/*
 * ̃\[XR[h blanco Frameworkɂ莩܂B
 */
package blanco.nlpack.generator.task.valueobject;

/**
 * NX [BlancoNLpackGeneratorPluginDirectory2JarProcess]̓̓o[IuWFNgNXłB
 */
public class BlancoNLpackGeneratorPluginDirectory2JarProcessInput {
    /**
     * tB[h [verbose]
     *
     * ڂ̌^ [boolean]<br>
     * Kl   [false]<br>
     * verbose[hœ삳邩ǂB
     */
    private boolean fVerbose = false;

    /**
     * tB[h [sourcedir]
     *
     * ڂ̌^ [java.lang.String]<br>
     * \[XfBNgB
     */
    private String fSourcedir;

    /**
     * tB[h [targetdir]
     *
     * ڂ̌^ [java.lang.String]<br>
     * Kl   [blanco.nl.jar]<br>
     * o͐tH_w肵܂B
     */
    private String fTargetdir = "blanco.nl.jar";

    /**
     * tB[h [verbose]̃Zb^[\bh
     *
     * ڂ̌^ [boolean]<br>
     * verbose[hœ삳邩ǂB
     *
     * @param argVerbose tB[h[verbose]Ɋi[l
     */
    public void setVerbose(final boolean argVerbose) {
        fVerbose = argVerbose;
    }

    /**
     * tB[h[verbose]̃Qb^[\bh
     *
     * ڂ̌^ [boolean]<br>
     * Kl   [false]<br>
     * verbose[hœ삳邩ǂB
     *
     * @return tB[h[verbose]Ɋi[Ăl
     */
    public boolean getVerbose() {
        return fVerbose;
    }

    /**
     * tB[h [sourcedir]̃Zb^[\bh
     *
     * ڂ̌^ [java.lang.String]<br>
     * \[XfBNgB
     *
     * @param argSourcedir tB[h[sourcedir]Ɋi[l
     */
    public void setSourcedir(final String argSourcedir) {
        fSourcedir = argSourcedir;
    }

    /**
     * tB[h[sourcedir]̃Qb^[\bh
     *
     * ڂ̌^ [java.lang.String]<br>
     * \[XfBNgB
     *
     * @return tB[h[sourcedir]Ɋi[Ăl
     */
    public String getSourcedir() {
        return fSourcedir;
    }

    /**
     * tB[h [targetdir]̃Zb^[\bh
     *
     * ڂ̌^ [java.lang.String]<br>
     * o͐tH_w肵܂B
     *
     * @param argTargetdir tB[h[targetdir]Ɋi[l
     */
    public void setTargetdir(final String argTargetdir) {
        fTargetdir = argTargetdir;
    }

    /**
     * tB[h[targetdir]̃Qb^[\bh
     *
     * ڂ̌^ [java.lang.String]<br>
     * Kl   [blanco.nl.jar]<br>
     * o͐tH_w肵܂B
     *
     * @return tB[h[targetdir]Ɋi[Ăl
     */
    public String getTargetdir() {
        return fTargetdir;
    }

    /**
     * ̃o[IuWFNg̕\擾܂B
     *
     * IuWFNg̃V[͈͂łtoStringȂ_ɒӂėpĂB
     *
     * @return o[IuWFNg̕\B
     */
    public String toString() {
        final StringBuffer buf = new StringBuffer();
        buf.append("blanco.nlpack.generator.task.valueobject.BlancoNLpackGeneratorPluginDirectory2JarProcessInput[");
        buf.append("verbose=" + fVerbose);
        buf.append(",sourcedir=" + fSourcedir);
        buf.append(",targetdir=" + fTargetdir);
        buf.append("]");
        return buf.toString();
    }
}

==> blancoNLpackGenerator-0.1.17-src.zip: blancoNLpackGenerator/blanco/main/blanco/nlpack/generator/task/valueobject/BlancoNLpackGeneratorPluginDirectory2JarProcessInput.java <==
/*
 * ̃\[XR[h blanco Frameworkɂ莩܂B
 */
package blanco.nlpack.generator.task.valueobject;

/**
 * NX [BlancoNLpackGeneratorPluginDirectory2JarProcess]̓̓o[IuWFNgNXłB
 */
public class BlancoNLpackGeneratorPluginDirectory2JarProcessInput {
    /**
     * verbose[hœ삳邩ǂB
     *
     * tB[h: [verbose]B
     * ftHg: [false]B
     */
    private boolean fVerbose = false;

    /**
     * \[XfBNgB
     *
     * tB[h: [sourcedir]B
     */
    private String fSourcedir;

    /**
     * o͐tH_w肵܂B
     *
     * tB[h: [targetdir]B
     * ftHg: [blanco.nl.jar]B
     */
    private String fTargetdir = "blanco.nl.jar";

    /**
     * tB[h [verbose] ̒lݒ肵܂B
     *
     * tB[h̐: [verbose[hœ삳邩ǂB]B
     *
     * @param argVerbose tB[h[verbose]ɐݒ肷lB
     */
    public void setVerbose(final boolean argVerbose) {
        fVerbose = argVerbose;
    }

    /**
     * tB[h [verbose] ̒l擾܂B
     *
     * tB[h̐: [verbose[hœ삳邩ǂB]B
     * ftHg: [false]B
     *
     * @return tB[h[verbose]擾lB
     */
    public boolean getVerbose() {
        return fVerbose;
    }

    /**
     * tB[h [sourcedir] ̒lݒ肵܂B
     *
     * tB[h̐: [\[XfBNgB]B
     *
     * @param argSourcedir tB[h[sourcedir]ɐݒ肷lB
     */
    public void setSourcedir(final String argSourcedir) {
        fSourcedir = argSourcedir;
    }

    /**
     * tB[h [sourcedir] ̒l擾܂B
     *
     * tB[h̐: [\[XfBNgB]B
     *
     * @return tB[h[sourcedir]擾lB
     */
    public String getSourcedir() {
        return fSourcedir;
    }

    /**
     * tB[h [targetdir] ̒lݒ肵܂B
     *
     * tB[h̐: [o͐tH_w肵܂B]B
     *
     * @param argTargetdir tB[h[targetdir]ɐݒ肷lB
     */
    public void setTargetdir(final String argTargetdir) {
        fTargetdir = argTargetdir;
    }

    /**
     * tB[h [targetdir] ̒l擾܂B
     *
     * tB[h̐: [o͐tH_w肵܂B]B
     * ftHg: [blanco.nl.jar]B
     *
     * @return tB[h[targetdir]擾lB
     */
    public String getTargetdir() {
        return fTargetdir;
    }

    /**
     * ̃o[IuWFNg̕\擾܂B
     *
     * <P>gp̒</P>
     * <UL>
     * <LI>IuWFNg̃V[͈͂̂ݕ񉻂̏ΏۂƂȂ܂B
     * <LI>IuWFNgzQƂĂꍇɂ́Ã\bh͎gȂłB
     * </UL>
     *
     * @return o[IuWFNg̕\B
     */
    @Override
    public String toString() {
        final StringBuffer buf = new StringBuffer();
        buf.append("blanco.nlpack.generator.task.valueobject.BlancoNLpackGeneratorPluginDirectory2JarProcessInput[");
        buf.append("verbose=" + fVerbose);
        buf.append(",sourcedir=" + fSourcedir);
        buf.append(",targetdir=" + fTargetdir);
        buf.append("]");
        return buf.toString();
    }
}
